/*
 * Copyright 2005-2006 Myriad Genetics, Inc.
 *
 * All rights reserved.
 */

#include "input.h"
#include "inputOrder.h"
#include "output.h"
#include <stdio.h>
#include <stdlib.h>

/* Swaps both maternal and paternal phases for a given set of markers in a
   pedigree.
 */
int main(int argc, char **argv)
{
    pedigree_t  ped;
    marker_t    **markers;
    int         numMarkers;
    int         i, j;
    int         swapMap[16] = {0,8,4,12,2,10,6,14,1,9,5,13,3,11,7,15};

    if (argc != 4) {
        fprintf(stderr, "Usage: %s <input ped> <marker file> <output file>\n",
                *argv);
        return EXIT_FAILURE;
    }
    
    if (!readFile(&ped, argv[1]))
        return EXIT_FAILURE;
    
    markers = readOrderFile(&ped, &numMarkers, argv[2]);
    if (markers == NULL) {
        freePed(&ped);
        return EXIT_FAILURE;
    }
    
    for (i = 0; i < numMarkers; ++i) {
        for (j = 0; j < ped.numInds; ++j) {
            markers[i]->obs[j] = swapMap[markers[i]->obs[j]];
        }
    }
    
    writePed(&ped, argv[3]);
    freePed(&ped);
    free(markers);
    
    return EXIT_SUCCESS;
}
